@@ -314,7 +314,16 @@ try {
                 logMessage("Scheduled backup completed successfully for user: $user");
                 $scheduledProcessed++;
             } else {
-                logMessage("Scheduled backup failed for user: $user", 'ERROR');
+                // Get detailed error message
+                $errorMessage = "Scheduled backup failed for user: $user";
+                if ($result && isset($result['error'])) {
+                    $errorMessage .= " - " . $result['error'];
+                } elseif ($result && isset($result['message'])) {
+                    $errorMessage .= " - " . $result['message'];
+                } elseif (!$result) {
+                    $errorMessage .= " - Backup operation returned null result";
+                }
+                logMessage($errorMessage, 'ERROR');
                 $scheduledFailed++;
             }
             
@@ -422,7 +431,16 @@ try {
                 $stmt->execute([$queueId]);
                 $queuedProcessed++;
             } else {
-                throw new Exception("Backup operation returned failure");
+                // Get detailed error message
+                $errorMessage = "Backup operation returned failure";
+                if ($result && isset($result['error'])) {
+                    $errorMessage = $result['error'];
+                } elseif ($result && isset($result['message'])) {
+                    $errorMessage = $result['message'];
+                } elseif (!$result) {
+                    $errorMessage = "Backup operation returned null result";
+                }
+                throw new Exception($errorMessage);
             }
             
         } catch (Exception $e) {
