@@ -301,13 +301,20 @@ class haproxy_manager {
     /**
      * Generate backend name from domain
      * 
-     * @param string $domain Domain name
-     * @return string Backend name
+     * Converts domain names to HAProxy-compatible backend names by replacing
+     * dots and special characters with underscores. The HAProxy service templates
+     * automatically append '-backend' suffix, so this method returns only the
+     * sanitized domain name (e.g., 'example.com' becomes 'example_com').
+     * 
+     * @param string $domain Domain name (e.g., 'example.com')
+     * @return string Sanitized backend name (e.g., 'example_com')
      */
     private function generateBackendName($domain) {
         // Remove dots and special characters, convert to lowercase
         $backend_name = preg_replace('/[^a-zA-Z0-9_]/', '_', strtolower($domain));
-        return $backend_name . '_backend';
+        // Don't append '_backend' here as the HAProxy service appends '-backend' itself
+        // Final HAProxy backend name will be: {sanitized_domain}-backend
+        return $backend_name;
     }
     
     /**
